@@ -6,7 +6,7 @@ import plotly.graph_objects as go
 from xarray import DataArray, Dataset
 
 from xarray_plotly import plotting
-from xarray_plotly.common import SlotValue, auto
+from xarray_plotly.common import Colors, SlotValue, auto
 from xarray_plotly.config import _options
 
 
@@ -34,7 +34,7 @@ class DataArrayPlotlyAccessor:
         ```
     """
 
-    __all__: ClassVar = ["line", "bar", "area", "scatter", "box", "imshow", "pie"]
+    __all__: ClassVar = ["line", "bar", "fast_bar", "area", "scatter", "box", "imshow", "pie"]
 
     def __init__(self, darray: DataArray) -> None:
         self._da = darray
@@ -53,6 +53,7 @@ class DataArrayPlotlyAccessor:
         facet_col: SlotValue = auto,
         facet_row: SlotValue = auto,
         animation_frame: SlotValue = auto,
+        colors: Colors = None,
         **px_kwargs: Any,
     ) -> go.Figure:
         """Create an interactive line plot.
@@ -67,6 +68,7 @@ class DataArrayPlotlyAccessor:
             facet_col: Dimension for subplot columns. Default: fifth dimension.
             facet_row: Dimension for subplot rows. Default: sixth dimension.
             animation_frame: Dimension for animation. Default: seventh dimension.
+            colors: Color specification (scale name, list, or dict). See module docs.
             **px_kwargs: Additional arguments passed to `plotly.express.line()`.
 
         Returns:
@@ -81,6 +83,7 @@ class DataArrayPlotlyAccessor:
             facet_col=facet_col,
             facet_row=facet_row,
             animation_frame=animation_frame,
+            colors=colors,
             **px_kwargs,
         )
 
@@ -93,6 +96,7 @@ class DataArrayPlotlyAccessor:
         facet_col: SlotValue = auto,
         facet_row: SlotValue = auto,
         animation_frame: SlotValue = auto,
+        colors: Colors = None,
         **px_kwargs: Any,
     ) -> go.Figure:
         """Create an interactive bar chart.
@@ -106,6 +110,7 @@ class DataArrayPlotlyAccessor:
             facet_col: Dimension for subplot columns. Default: fourth dimension.
             facet_row: Dimension for subplot rows. Default: fifth dimension.
             animation_frame: Dimension for animation. Default: sixth dimension.
+            colors: Color specification (scale name, list, or dict). See module docs.
             **px_kwargs: Additional arguments passed to `plotly.express.bar()`.
 
         Returns:
@@ -119,6 +124,7 @@ class DataArrayPlotlyAccessor:
             facet_col=facet_col,
             facet_row=facet_row,
             animation_frame=animation_frame,
+            colors=colors,
             **px_kwargs,
         )
 
@@ -131,6 +137,7 @@ class DataArrayPlotlyAccessor:
         facet_col: SlotValue = auto,
         facet_row: SlotValue = auto,
         animation_frame: SlotValue = auto,
+        colors: Colors = None,
         **px_kwargs: Any,
     ) -> go.Figure:
         """Create an interactive stacked area chart.
@@ -144,6 +151,7 @@ class DataArrayPlotlyAccessor:
             facet_col: Dimension for subplot columns. Default: fourth dimension.
             facet_row: Dimension for subplot rows. Default: fifth dimension.
             animation_frame: Dimension for animation. Default: sixth dimension.
+            colors: Color specification (scale name, list, or dict). See module docs.
             **px_kwargs: Additional arguments passed to `plotly.express.area()`.
 
         Returns:
@@ -157,6 +165,45 @@ class DataArrayPlotlyAccessor:
             facet_col=facet_col,
             facet_row=facet_row,
             animation_frame=animation_frame,
+            colors=colors,
+            **px_kwargs,
+        )
+
+    def fast_bar(
+        self,
+        *,
+        x: SlotValue = auto,
+        color: SlotValue = auto,
+        facet_col: SlotValue = auto,
+        facet_row: SlotValue = auto,
+        animation_frame: SlotValue = auto,
+        colors: Colors = None,
+        **px_kwargs: Any,
+    ) -> go.Figure:
+        """Create a bar-like chart using stacked areas for better performance.
+
+        Slot order: x -> color -> facet_col -> facet_row -> animation_frame
+
+        Args:
+            x: Dimension for x-axis. Default: first dimension.
+            color: Dimension for color/stacking. Default: second dimension.
+            facet_col: Dimension for subplot columns. Default: third dimension.
+            facet_row: Dimension for subplot rows. Default: fourth dimension.
+            animation_frame: Dimension for animation. Default: fifth dimension.
+            colors: Color specification (scale name, list, or dict). See module docs.
+            **px_kwargs: Additional arguments passed to `plotly.express.area()`.
+
+        Returns:
+            Interactive Plotly Figure.
+        """
+        return plotting.fast_bar(
+            self._da,
+            x=x,
+            color=color,
+            facet_col=facet_col,
+            facet_row=facet_row,
+            animation_frame=animation_frame,
+            colors=colors,
             **px_kwargs,
         )
 
@@ -170,6 +217,7 @@ class DataArrayPlotlyAccessor:
         facet_col: SlotValue = auto,
         facet_row: SlotValue = auto,
         animation_frame: SlotValue = auto,
+        colors: Colors = None,
         **px_kwargs: Any,
     ) -> go.Figure:
         """Create an interactive scatter plot.
@@ -188,6 +236,7 @@ class DataArrayPlotlyAccessor:
             facet_col: Dimension for subplot columns. Default: fourth dimension.
             facet_row: Dimension for subplot rows. Default: fifth dimension.
             animation_frame: Dimension for animation. Default: sixth dimension.
+            colors: Color specification (scale name, list, or dict). See module docs.
             **px_kwargs: Additional arguments passed to `plotly.express.scatter()`.
 
         Returns:
@@ -202,6 +251,7 @@ class DataArrayPlotlyAccessor:
             facet_col=facet_col,
             facet_row=facet_row,
             animation_frame=animation_frame,
+            colors=colors,
             **px_kwargs,
         )
 
@@ -213,6 +263,7 @@ class DataArrayPlotlyAccessor:
         facet_col: SlotValue = None,
         facet_row: SlotValue = None,
         animation_frame: SlotValue = None,
+        colors: Colors = None,
         **px_kwargs: Any,
     ) -> go.Figure:
         """Create an interactive box plot.
@@ -228,6 +279,7 @@ class DataArrayPlotlyAccessor:
             facet_col: Dimension for subplot columns. Default: None (aggregated).
             facet_row: Dimension for subplot rows. Default: None (aggregated).
             animation_frame: Dimension for animation. Default: None (aggregated).
+            colors: Color specification (scale name, list, or dict). See module docs.
             **px_kwargs: Additional arguments passed to `plotly.express.box()`.
 
         Returns:
@@ -240,6 +292,7 @@ class DataArrayPlotlyAccessor:
             facet_col=facet_col,
             facet_row=facet_row,
             animation_frame=animation_frame,
+            colors=colors,
             **px_kwargs,
         )
 
@@ -251,18 +304,25 @@ class DataArrayPlotlyAccessor:
         facet_col: SlotValue = auto,
         animation_frame: SlotValue = auto,
         robust: bool = False,
+        colors: Colors = None,
         **px_kwargs: Any,
     ) -> go.Figure:
         """Create an interactive heatmap image.
 
         Slot order: y (rows) -> x (columns) -> facet_col -> animation_frame
 
+        Note:
+            **Difference from px.imshow**: Color bounds are computed from the
+            entire dataset by default, ensuring consistent coloring across
+            animation frames. Use `zmin`/`zmax` to override.
+
         Args:
             x: Dimension for x-axis (columns). Default: second dimension.
             y: Dimension for y-axis (rows). Default: first dimension.
             facet_col: Dimension for subplot columns. Default: third dimension.
             animation_frame: Dimension for animation. Default: fourth dimension.
             robust: If True, use 2nd/98th percentiles for color bounds (handles outliers).
+            colors: Color scale name (e.g., "Viridis", "RdBu"). See module docs.
             **px_kwargs: Additional arguments passed to `plotly.express.imshow()`.
                 Use `zmin` and `zmax` to manually set color scale bounds.
 
@@ -276,6 +336,7 @@ class DataArrayPlotlyAccessor:
             facet_col=facet_col,
             animation_frame=animation_frame,
             robust=robust,
+            colors=colors,
             **px_kwargs,
         )
 
@@ -286,6 +347,7 @@ class DataArrayPlotlyAccessor:
         color: SlotValue = None,
         facet_col: SlotValue = auto,
         facet_row: SlotValue = auto,
+        colors: Colors = None,
         **px_kwargs: Any,
     ) -> go.Figure:
         """Create an interactive pie chart.
@@ -297,6 +359,7 @@ class DataArrayPlotlyAccessor:
             color: Dimension for color grouping. Default: None (uses names).
             facet_col: Dimension for subplot columns. Default: second dimension.
             facet_row: Dimension for subplot rows. Default: third dimension.
+            colors: Color specification (scale name, list, or dict). See module docs.
             **px_kwargs: Additional arguments passed to `plotly.express.pie()`.
 
         Returns:
@@ -308,6 +371,7 @@ class DataArrayPlotlyAccessor:
             color=color,
             facet_col=facet_col,
             facet_row=facet_row,
+            colors=colors,
             **px_kwargs,
         )
 
@@ -344,7 +408,7 @@ class DatasetPlotlyAccessor:
         ```
     """
 
-    __all__: ClassVar = ["line", "bar", "area", "scatter", "box", "pie"]
+    __all__: ClassVar = ["line", "bar", "fast_bar", "area", "scatter", "box", "pie"]
 
     def __init__(self, dataset: Dataset) -> None:
         self._ds = dataset
@@ -387,6 +451,7 @@ class DatasetPlotlyAccessor:
         facet_col: SlotValue = auto,
         facet_row: SlotValue = auto,
         animation_frame: SlotValue = auto,
+        colors: Colors = None,
         **px_kwargs: Any,
     ) -> go.Figure:
         """Create an interactive line plot.
@@ -400,6 +465,7 @@ class DatasetPlotlyAccessor:
             facet_col: Dimension for subplot columns.
             facet_row: Dimension for subplot rows.
             animation_frame: Dimension for animation.
+            colors: Color specification (scale name, list, or dict). See module docs.
             **px_kwargs: Additional arguments passed to `plotly.express.line()`.
 
         Returns:
@@ -415,6 +481,7 @@ class DatasetPlotlyAccessor:
             facet_col=facet_col,
             facet_row=facet_row,
             animation_frame=animation_frame,
+            colors=colors,
             **px_kwargs,
         )
 
@@ -428,6 +495,7 @@ class DatasetPlotlyAccessor:
         facet_col: SlotValue = auto,
         facet_row: SlotValue = auto,
         animation_frame: SlotValue = auto,
+        colors: Colors = None,
         **px_kwargs: Any,
     ) -> go.Figure:
         """Create an interactive bar chart.
@@ -440,6 +508,7 @@ class DatasetPlotlyAccessor:
             facet_col: Dimension for subplot columns.
             facet_row: Dimension for subplot rows.
             animation_frame: Dimension for animation.
+            colors: Color specification (scale name, list, or dict). See module docs.
             **px_kwargs: Additional arguments passed to `plotly.express.bar()`.
 
         Returns:
@@ -454,6 +523,7 @@ class DatasetPlotlyAccessor:
             facet_col=facet_col,
             facet_row=facet_row,
             animation_frame=animation_frame,
+            colors=colors,
             **px_kwargs,
         )
 
@@ -467,6 +537,7 @@ class DatasetPlotlyAccessor:
         facet_col: SlotValue = auto,
         facet_row: SlotValue = auto,
         animation_frame: SlotValue = auto,
+        colors: Colors = None,
         **px_kwargs: Any,
     ) -> go.Figure:
         """Create an interactive stacked area chart.
@@ -479,6 +550,7 @@ class DatasetPlotlyAccessor:
             facet_col: Dimension for subplot columns.
             facet_row: Dimension for subplot rows.
             animation_frame: Dimension for animation.
+            colors: Color specification (scale name, list, or dict). See module docs.
             **px_kwargs: Additional arguments passed to `plotly.express.area()`.
 
         Returns:
@@ -493,6 +565,46 @@ class DatasetPlotlyAccessor:
             facet_col=facet_col,
             facet_row=facet_row,
             animation_frame=animation_frame,
+            colors=colors,
+            **px_kwargs,
+        )
+
+    def fast_bar(
+        self,
+        var: str | None = None,
+        *,
+        x: SlotValue = auto,
+        color: SlotValue = auto,
+        facet_col: SlotValue = auto,
+        facet_row: SlotValue = auto,
+        animation_frame: SlotValue = auto,
+        colors: Colors = None,
+        **px_kwargs: Any,
+    ) -> go.Figure:
+        """Create a bar-like chart using stacked areas for better performance.
+
+        Args:
+            var: Variable to plot. If None, plots all variables with "variable" dimension.
+            x: Dimension for x-axis.
+            color: Dimension for color/stacking.
+            facet_col: Dimension for subplot columns.
+            facet_row: Dimension for subplot rows.
+            animation_frame: Dimension for animation.
+            colors: Color specification (scale name, list, or dict). See module docs.
+            **px_kwargs: Additional arguments passed to `plotly.express.area()`.
+
+        Returns:
+            Interactive Plotly Figure.
+        """
+        da = self._get_dataarray(var)
+        return plotting.fast_bar(
+            da,
+            x=x,
+            color=color,
+            facet_col=facet_col,
+            facet_row=facet_row,
+            animation_frame=animation_frame,
+            colors=colors,
             **px_kwargs,
         )
 
@@ -507,6 +619,7 @@ class DatasetPlotlyAccessor:
         facet_col: SlotValue = auto,
         facet_row: SlotValue = auto,
         animation_frame: SlotValue = auto,
+        colors: Colors = None,
         **px_kwargs: Any,
     ) -> go.Figure:
         """Create an interactive scatter plot.
@@ -520,6 +633,7 @@ class DatasetPlotlyAccessor:
             facet_col: Dimension for subplot columns.
             facet_row: Dimension for subplot rows.
             animation_frame: Dimension for animation.
+            colors: Color specification (scale name, list, or dict). See module docs.
             **px_kwargs: Additional arguments passed to `plotly.express.scatter()`.
 
         Returns:
@@ -535,6 +649,7 @@ class DatasetPlotlyAccessor:
             facet_col=facet_col,
             facet_row=facet_row,
             animation_frame=animation_frame,
+            colors=colors,
             **px_kwargs,
         )
 
@@ -547,6 +662,7 @@ class DatasetPlotlyAccessor:
         facet_col: SlotValue = None,
         facet_row: SlotValue = None,
         animation_frame: SlotValue = None,
+        colors: Colors = None,
         **px_kwargs: Any,
     ) -> go.Figure:
         """Create an interactive box plot.
@@ -558,6 +674,7 @@ class DatasetPlotlyAccessor:
             facet_col: Dimension for subplot columns.
             facet_row: Dimension for subplot rows.
             animation_frame: Dimension for animation.
+            colors: Color specification (scale name, list, or dict). See module docs.
             **px_kwargs: Additional arguments passed to `plotly.express.box()`.
 
         Returns:
@@ -571,6 +688,7 @@ class DatasetPlotlyAccessor:
             facet_col=facet_col,
             facet_row=facet_row,
             animation_frame=animation_frame,
+            colors=colors,
             **px_kwargs,
         )
 
@@ -582,6 +700,7 @@ class DatasetPlotlyAccessor:
         color: SlotValue = None,
         facet_col: SlotValue = auto,
         facet_row: SlotValue = auto,
+        colors: Colors = None,
         **px_kwargs: Any,
     ) -> go.Figure:
         """Create an interactive pie chart.
@@ -592,6 +711,7 @@ class DatasetPlotlyAccessor:
             color: Dimension for color grouping.
             facet_col: Dimension for subplot columns.
             facet_row: Dimension for subplot rows.
+            colors: Color specification (scale name, list, or dict). See module docs.
             **px_kwargs: Additional arguments passed to `plotly.express.pie()`.
 
         Returns:
@@ -604,5 +724,6 @@ class DatasetPlotlyAccessor:
             color=color,
             facet_col=facet_col,
             facet_row=facet_row,
+            colors=colors,
             **px_kwargs,
         )
