@@ -5,7 +5,7 @@ Helper functions for combining and manipulating Plotly figures.
 from __future__ import annotations
 
 import copy
-from typing import TYPE_CHECKING
+from typing import TYPE_CHECKING, Any
 
 if TYPE_CHECKING:
     from collections.abc import Iterator
@@ -13,7 +13,7 @@ if TYPE_CHECKING:
     import plotly.graph_objects as go
 
 
-def _iter_all_traces(fig: go.Figure) -> Iterator:
+def _iter_all_traces(fig: go.Figure) -> Iterator[Any]:
     """Iterate over all traces in a figure, including animation frames.
 
     Yields traces from fig.data first, then from each frame in fig.frames.
@@ -107,7 +107,7 @@ def _merge_frames(
     overlays: list[go.Figure],
     base_trace_count: int,
     overlay_trace_counts: list[int],
-) -> list:
+) -> list[go.Frame]:
     """Merge animation frames from base and overlay figures.
 
     Args:
@@ -142,6 +142,7 @@ def _merge_frames(
                 data=merged_data,
                 name=frame_name,
                 traces=list(range(base_trace_count + sum(overlay_trace_counts))),
+                layout=base_frame.layout,
             )
         )
 
@@ -307,6 +308,13 @@ def add_secondary_y(
     # Build mapping from primary y-axes to secondary y-axes
     y_mapping = _build_secondary_y_mapping(base_axes)
 
+    # Build x-y correspondence from base_axes (which x-axis pairs with which y-axis)
+    x_for_y = {yaxis: xaxis for xaxis, yaxis in base_axes}
+
+    # Find the rightmost x-axis (highest number) to determine which secondary axis shows ticks
+    rightmost_x = max(x_for_y.values(), key=lambda x: int(x[1:]) if x != "x" else 1)
+    rightmost_primary_y = next(y for y, x in x_for_y.items() if x == rightmost_x)
+
     # Create new figure with base's layout
     combined = go.Figure(layout=copy.deepcopy(base.layout))
 
@@ -321,24 +329,32 @@ def add_secondary_y(
         trace_copy.yaxis = y_mapping[original_yaxis]
         combined.add_trace(trace_copy)
 
+    # Get the rightmost secondary y-axis name for linking
+    rightmost_secondary_y = y_mapping[rightmost_primary_y]
+
     # Configure secondary y-axes
     for primary_yaxis, secondary_yaxis in y_mapping.items():
-        # Get title - only set on first secondary axis or use provided title
+        is_rightmost = primary_yaxis == rightmost_primary_y
+
+        # Get title - only set on rightmost secondary axis
         title = None
-        if secondary_y_title is not None:
-            # Only set title on the first secondary axis to avoid repetition
-            if primary_yaxis == "y":
+        if is_rightmost:
+            if secondary_y_title is not None:
                 title = secondary_y_title
-        elif primary_yaxis == "y" and secondary.layout.yaxis and secondary.layout.yaxis.title:
-            # Try to get from secondary's layout
-            title = secondary.layout.yaxis.title.text
+            elif secondary.layout.yaxis and secondary.layout.yaxis.title:
+                title = secondary.layout.yaxis.title.text
 
         # Configure the secondary axis
+        # Anchor to the corresponding x-axis so it appears on the right side of its subplot
         axis_config = {
             "title": title,
             "overlaying": primary_yaxis,
             "side": "right",
-            "anchor": "free" if primary_yaxis != "y" else None,
+            "anchor": x_for_y[primary_yaxis],
+            # Only show ticks on the rightmost secondary axis
+            "showticklabels": is_rightmost,
+            # Link non-rightmost axes to the rightmost for consistent scaling
+            "matches": None if is_rightmost else rightmost_secondary_y,
         }
         # Remove None values
         axis_config = {k: v for k, v in axis_config.items() if v is not None}
@@ -359,7 +375,7 @@ def _merge_secondary_y_frames(
     base: go.Figure,
     secondary: go.Figure,
     y_mapping: dict[str, str],
-) -> list:
+) -> list[go.Frame]:
     """Merge animation frames for secondary y-axis combination.
 
     Args:
@@ -403,13 +419,16 @@ def _merge_secondary_y_frames(
                 data=merged_data,
                 name=frame_name,
                 traces=list(range(base_trace_count + secondary_trace_count)),
+                layout=base_frame.layout,
             )
         )
 
     return merged_frames
 
 
-def update_traces(fig: go.Figure, selector: dict | None = None, **kwargs) -> go.Figure:
+def update_traces(
+    fig: go.Figure, selector: dict[str, Any] | None = None, **kwargs: Any
+) -> go.Figure:
     """Update traces in both base figure and all animation frames.
 
     Plotly's `update_traces()` only updates the base figure, not animation frames.
